@@ -1,51 +1,24 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
+
 package com.openexchange.admin.console;
 
 import java.util.ArrayList;
@@ -55,6 +28,7 @@ import java.util.Hashtable;
 import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
+import java.util.Optional;
 import com.openexchange.admin.rmi.exceptions.MissingOptionException;
 import com.openexchange.java.Strings;
 
@@ -64,6 +38,7 @@ import com.openexchange.java.Strings;
  * 2. The ability to have mandatory options
  */
 public class AdminParser extends CLIParser {
+
     public enum NeededQuadState {
         notneeded,
         possibly,
@@ -110,10 +85,15 @@ public class AdminParser extends CLIParser {
     private final CLIOption noNewlineOption;
 
     private boolean allowDynamic;
+    private boolean allowFlexibleDynamic;
+
+    private Optional<String> dynamicDescription;
+    private Optional<String> dynamicRemoveDescription;
 
     private final Map<String, Map<String, String>> dynamicMaps = new HashMap<String, Map<String, String>>();
 
     private static class OptionInfo {
+
         public NeededQuadState needed = NeededQuadState.notneeded;
 
         public CLIOption option = null;
@@ -207,7 +187,6 @@ public class AdminParser extends CLIParser {
         this.responseTimeoutOption = this.addOption(OPT_RESPONSETIMEOUT_LONG, OPT_RESPONSETIMEOUT_LONG, "response timeout in seconds for reading response from the backend (default 0s; infinite)", false, true);
     }
 
-
     /**
      * This method is used to add an option with a mandatory field
      *
@@ -295,7 +274,7 @@ public class AdminParser extends CLIParser {
         this.optinfolist.add(new OptionInfo(NeededQuadState.notneeded, retval, longForm, description));
         return retval;
     }
-    
+
     /**
      * Adds an option at the given position
      * 
@@ -479,7 +458,7 @@ public class AdminParser extends CLIParser {
 
     private String[] extractDynamic(String[] args) {
         List<String> staticArgs = new ArrayList<String>(args.length);
-        for(String arg : args) {
+        for (String arg : args) {
             if (isExtendedOption(arg) && isDynamicOption(arg)) {
                 parseDynamicOption(arg);
             } else {
@@ -490,37 +469,41 @@ public class AdminParser extends CLIParser {
     }
 
     private void parseDynamicOption(String arg) {
-
         String namespace = null;
         String name = null;
         String value = null;
 
         int slashPos = arg.indexOf('/');
 
-
-        if (arg.startsWith("--remove-")) {
-            namespace = arg.substring(9, slashPos);
-            name = arg.substring(slashPos+1);
-        } else {
+        if (allowFlexibleDynamic) {
+            namespace = arg.substring(2, slashPos);
             int equalPos = arg.indexOf('=');
-
+            name = equalPos > 0 ? arg.substring(slashPos + 1, equalPos) : arg.substring(slashPos + 1);
+            if (equalPos > 0) {
+                value = arg.substring(equalPos + 1);
+            }
+        } else if (arg.startsWith("--remove-")) {
+            namespace = arg.substring(9, slashPos);
+            name = arg.substring(slashPos + 1);
+        } else {
             if (slashPos == -1) {
                 return;
             }
 
+            int equalPos = arg.indexOf('=');
+
             if (equalPos == -1) {
                 return;
             }
 
-            namespace = arg.substring(2,slashPos);
-            name = arg.substring(slashPos+1, equalPos);
-            value = arg.substring(equalPos+1);
+            namespace = arg.substring(2, slashPos);
+            name = arg.substring(slashPos + 1, equalPos);
+            value = arg.substring(equalPos + 1);
         }
 
         getDynamicMap(namespace).put(name, value);
     }
 
-
     private Map<String, String> getDynamicMap(String namespace) {
         Map<String, String> namespacedMap = dynamicMaps.get(namespace);
         if (namespacedMap == null) {
@@ -530,16 +513,14 @@ public class AdminParser extends CLIParser {
         return namespacedMap;
     }
 
-
     private boolean isDynamicOption(String arg) {
         int slashPos = arg.indexOf('/');
         if (slashPos == -1) {
             return false;
         }
-        return slashPos < arg.indexOf('=') || arg.startsWith("--remove-");
+        return allowFlexibleDynamic || slashPos < arg.indexOf('=') || arg.startsWith("--remove-");
     }
 
-
     private boolean isExtendedOption(String arg) {
         return arg.startsWith("--");
     }
@@ -549,14 +530,13 @@ public class AdminParser extends CLIParser {
     }
 
     public final void setExtendedOptions() {
-        this.extendedoption = addOption(1, OPT_EXTENDED_LONG, OPT_EXTENDED_LONG, "Set this if you want to see all options, use this instead of help option", false,false);
+        this.extendedoption = addOption(1, OPT_EXTENDED_LONG, OPT_EXTENDED_LONG, "Set this if you want to see all options, use this instead of help option", false, false);
     }
 
     public final void printEnvUsage() {
-        System.out.println("\nThe following environment variables and their current value are known\n" +
-        		"and can be modified to change behaviour:\n");
+        System.out.println("\nThe following environment variables and their current value are known\n" + "and can be modified to change behaviour:\n");
         final Hashtable<String, String> env = BasicCommandlineOptions.getEnvOptions();
-        for( final Entry<String, String> entry : env.entrySet()) {
+        for (final Entry<String, String> entry : env.entrySet()) {
             System.out.println("\t" + entry.getKey() + "=" + entry.getValue());
         }
         System.out.println("\n");
@@ -569,8 +549,8 @@ public class AdminParser extends CLIParser {
     public final void printUsage() {
         System.out.print("Usage: " + this.appname);
         System.out.println(" " + usage);
-        if (Strings.isNotEmpty(cltDescription)){
-            System.out.println(cltDescription+"\n");
+        if (Strings.isNotEmpty(cltDescription)) {
+            System.out.println(cltDescription + "\n");
         }
 
         for (final OptionInfo optInfo : this.optinfolist) {
@@ -578,6 +558,9 @@ public class AdminParser extends CLIParser {
                 basicOutput(optInfo);
             }
         }
+        if (allowDynamic && extendedoption == null && (dynamicDescription.isPresent() || dynamicRemoveDescription.isPresent())) {
+            printDynamicInfo();
+        }
         printFinalLines();
     }
 
@@ -592,13 +575,16 @@ public class AdminParser extends CLIParser {
     public final void printUsageExtended() {
         System.out.println("Usage: " + this.appname);
         System.out.println(" " + usage);
-        if (Strings.isNotEmpty(cltDescription)){
-            System.out.println("Description: "+cltDescription);
+        if (Strings.isNotEmpty(cltDescription)) {
+            System.out.println("Description: " + cltDescription);
         }
 
         for (final OptionInfo optInfo : this.optinfolist) {
             basicOutput(optInfo);
         }
+        if (allowDynamic && (dynamicDescription.isPresent() || dynamicRemoveDescription.isPresent())) {
+            printDynamicInfo();
+        }
         printFinalLines();
     }
 
@@ -653,6 +639,18 @@ public class AdminParser extends CLIParser {
         }
     }
 
+    private final void printDynamicInfo() {
+        final String format_this = " %s %-45s%-2s%-28s\n";
+        if (dynamicDescription.isPresent()) {
+            final Object[] format_with = { "  ", "--[namespace]/[key]=[value]", getrightmarker(NeededQuadState.notneeded), dynamicDescription.get() };
+            System.out.format(format_this, format_with);
+        }
+        if (dynamicRemoveDescription.isPresent()) {
+            final Object[] remove_format_with = { "  ", "--remove-[namespace]/[key]=[value]", getrightmarker(NeededQuadState.notneeded), dynamicRemoveDescription.get() };
+            System.out.format(format_this, remove_format_with);
+        }
+    }
+
     private NeededQuadState convertBooleantoTriState(final boolean needed) {
         return needed ? NeededQuadState.needed : NeededQuadState.notneeded;
     }
@@ -662,11 +660,11 @@ public class AdminParser extends CLIParser {
         final HashSet<String> longset = new HashSet<String>();
         for (final OptionInfo optinfo : this.optinfolist) {
             if (null != optinfo.shortForm && !set.add(optinfo.shortForm)) {
-                System.err.println(this.appname + ": The option: " + optinfo.shortForm + " for "+ optinfo.description + " is duplicate");
+                System.err.println(this.appname + ": The option: " + optinfo.shortForm + " for " + optinfo.description + " is duplicate");
                 System.exit(1);
             }
             if (null != optinfo.longForm && !longset.add(optinfo.longForm)) {
-                System.err.println(this.appname + ": The option: " + optinfo.longForm + " for "+ optinfo.description + " is duplicate");
+                System.err.println(this.appname + ": The option: " + optinfo.longForm + " for " + optinfo.description + " is duplicate");
                 System.exit(1);
             }
         }
@@ -674,26 +672,47 @@ public class AdminParser extends CLIParser {
     }
 
     private String getrightmarker(final NeededQuadState needed) {
-        if (needed == NeededQuadState.needed) {
-            return "*";
-        } else if (needed == NeededQuadState.possibly) {
-            return "?";
-        } else if (needed == NeededQuadState.eitheror) {
-            return "|";
-        } else {
-            return " ";
+        switch (needed) {
+            case needed:
+                return "*";
+            case possibly:
+                return "?";
+            case eitheror:
+                return "|";
+            default:
+                return " ";
         }
     }
 
-
     public void allowDynamicOptions() {
-        allowDynamic=true;
+        allowDynamic = true;
+        dynamicDescription = Optional.empty();
+        dynamicRemoveDescription = Optional.empty();
+    }
+
+    /**
+     * Allows dynamic options to be parsed. If a description is set then a help text is printed in the extended or normal help output
+     *
+     * @param description The help text description for the dynamic options
+     * @param removeDescription The help text description for the remove dynamic option
+     */
+    public void allowDynamicOptions(Optional<String> description, Optional<String> removeDescription) {
+        allowDynamic = true;
+        dynamicDescription = description;
+        dynamicRemoveDescription = removeDescription;
     }
 
     public void forbidDynamicOptions() {
-        allowDynamic=false;
+        allowDynamic = false;
     }
 
+    public void allowFlexibleDynamicOptions() {
+        allowFlexibleDynamic = true;
+    }
+
+    public void forbidFlexibleDynamicOptions() {
+        allowFlexibleDynamic = false;
+    }
 
     public Map<String, Map<String, String>> getDynamicArguments() {
         return dynamicMaps;
