@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -57,7 +29,6 @@ import com.openexchange.admin.console.AdminParser.NeededQuadState;
 import com.openexchange.admin.rmi.dataobjects.Context;
 import com.openexchange.admin.rmi.dataobjects.Credentials;
 import com.openexchange.admin.rmi.dataobjects.ExtendableDataObject;
-import com.openexchange.admin.rmi.exceptions.InvalidCredentialsException;
 import com.openexchange.admin.rmi.exceptions.InvalidDataException;
 import com.openexchange.admin.rmi.exceptions.MissingOptionException;
 import com.openexchange.admin.rmi.extensions.OXCommonExtensionInterface;
@@ -68,6 +39,7 @@ import com.openexchange.admin.rmi.extensions.OXCommonExtensionInterface;
  * @author cutmasta,d7
  *
  */
+@SuppressWarnings("deprecation")
 public abstract class BasicCommandlineOptions {
 
     private static final char dividechar = ' ';
@@ -197,7 +169,7 @@ public abstract class BasicCommandlineOptions {
     }
 
     public static final Hashtable<String, String> getEnvOptions() {
-        final Hashtable<String, String> opts = new Hashtable<String, String>();
+        final Hashtable<String, String> opts = new Hashtable<>();
         for (final String opt : ENV_OPTIONS) {
             try {
                 final Field f = BasicCommandlineOptions.class.getDeclaredField(opt);
@@ -257,7 +229,7 @@ public abstract class BasicCommandlineOptions {
         }
     }
 
-    protected final void printServerException(final Exception e, final AdminParser parser) {
+    protected static final void printServerException(final Exception e, final AdminParser parser) {
         StringBuilder output = new StringBuilder();
         final String msg = e.getMessage();
         if (parser != null && parser.checkNoNewLine()) {
@@ -286,7 +258,7 @@ public abstract class BasicCommandlineOptions {
     //        System.err.println("RMI module "+nbe.getMessage()+" not available on server");
     //    }
 
-    protected final void printError(final String msg, final AdminParser parser) {
+    protected static final void printError(final String msg, final AdminParser parser) {
         String output = null;
         if (parser == null) {
             output = msg;
@@ -393,48 +365,31 @@ public abstract class BasicCommandlineOptions {
     }
 
     protected final CLIOption setLongOpt(final AdminParser admp, final String longopt, final String description, final boolean hasarg, final boolean required) {
-
-        final CLIOption retval = admp.addOption(longopt, longopt, description, required, hasarg);
-        //        //OptionBuilder.withLongOpt( longopt ).withDescription( description ).withValueSeparator( '=' ).create();
-        //        if (hasarg) {
-        //            retval.hasArg();
-        //        }
-        //        retval.setRequired(required);
-        return retval;
+        return admp.addOption(longopt, longopt, description, required, hasarg);
     }
 
     protected final CLIOption setLongOpt(final AdminParser admp, final String longopt, final String description, final boolean hasarg, final boolean required, final boolean extended) {
-
-        final CLIOption retval = admp.addOption(longopt, longopt, description, required, hasarg, extended);
-        return retval;
+        return admp.addOption(longopt, longopt, description, required, hasarg, extended);
     }
 
     protected final CLIOption setLongOpt(final AdminParser admp, final String longopt, final String argdescription, final String description, final boolean hasarg, final boolean required, final boolean extended) {
-
-        final CLIOption retval = admp.addOption(longopt, argdescription, description, required, hasarg, extended);
-        return retval;
+        return admp.addOption(longopt, argdescription, description, required, hasarg, extended);
     }
 
     protected final CLIOption setIntegerLongOpt(final AdminParser admp, final String longopt, final String argdescription, final String description, final boolean hasarg, final boolean required, final boolean extended) {
-
-        final CLIOption retval = admp.addIntegerOption(longopt, argdescription, description, required, hasarg, extended);
-        return retval;
+        return admp.addIntegerOption(longopt, argdescription, description, required, hasarg, extended);
     }
 
     protected final CLIOption setSettableBooleanLongOpt(final AdminParser admp, final String longopt, final String argdescription, final String description, final boolean hasarg, final boolean required, final boolean extended) {
-
-        final CLIOption retval = admp.addSettableBooleanOption(longopt, argdescription, description, required, hasarg, extended);
-        return retval;
+        return admp.addSettableBooleanOption(longopt, argdescription, description, required, hasarg, extended);
     }
 
     protected final CLIOption setShortLongOpt(final AdminParser admp, final char shortopt, final String longopt, final String argdescription, final String description, final boolean required) {
-        final CLIOption retval = admp.addOption(shortopt, longopt, argdescription, description, required);
-        return retval;
+        return admp.addOption(shortopt, longopt, argdescription, description, required);
     }
 
     protected final CLIOption setShortLongOpt(final AdminParser admp, final char shortopt, final String longopt, final String description, final boolean hasarg, final NeededQuadState required) {
-        final CLIOption retval = admp.addOption(shortopt, longopt, longopt, description, required, hasarg);
-        return retval;
+        return admp.addOption(shortopt, longopt, longopt, description, required, hasarg);
     }
 
     protected final CLIOption setShortLongOptWithDefault(final AdminParser admp, final char shortopt, final String longopt, final String description, final String defaultvalue, final boolean hasarg, final NeededQuadState required) {
@@ -537,7 +492,7 @@ public abstract class BasicCommandlineOptions {
         setAdminPassOption(parser);
     }
 
-    protected void sysexit(final int exitcode) {
+    protected static void sysexit(final int exitcode) {
         // see http://java.sun.com/j2se/1.5.0/docs/guide/rmi/faq.html#leases
         System.gc();
         System.runFinalization();
@@ -559,9 +514,8 @@ public abstract class BasicCommandlineOptions {
      *
      * @param parser The {@link AdminParser}
      * @return The {@link Credentials}
-     * @throws InvalidCredentialsException in case the credentials are missing
      */
-    protected final Credentials credentialsparsing(final AdminParser parser) throws InvalidCredentialsException {
+    protected final Credentials credentialsparsing(final AdminParser parser) {
         // prefer password from options
         String password = (String) parser.getOptionValue(this.adminPassOption);
         if (null == password && null != ADMIN_PASSWORD) {
@@ -646,7 +600,7 @@ public abstract class BasicCommandlineOptions {
             // fill up part
             try {
                 columnsizes[i] = Integer.parseInt(columnsizesandalignments[i].substring(0, columnsizesandalignments[i].length() - 1));
-            } catch (NumberFormatException e) {
+            } catch (@SuppressWarnings("unused") NumberFormatException e) {
                 // there's no number, so use longest line as alignment value
                 columnsizes[i] = longestLine(data, columnnames, i);
             }
