@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -69,6 +41,7 @@ import org.apache.commons.cli.UnrecognizedOptionException;
  *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
+@SuppressWarnings("deprecation")
 public class CLIParser {
 
     private static final String OPT_START = "--";
@@ -99,8 +72,8 @@ public class CLIParser {
         super();
         this.posix = posix;
         cliOptions = posix ? new Options() : null;
-        options = new HashMap<String, CLIOption>(16);
-        values = new HashMap<String, List<Object>>(16);
+        options = new HashMap<>(16);
+        values = new HashMap<>(16);
     }
 
     /**
@@ -289,7 +262,7 @@ public class CLIParser {
      * @return The parsed values of all occurrences of given option
      */
     public final Collection<Object> getOptionValues(final CLIOption option) {
-        final List<Object> result = new ArrayList<Object>(2);
+        final List<Object> result = new ArrayList<>(2);
 
         while (true) {
             final Object o = getOptionValue(option, null, true);
@@ -482,7 +455,7 @@ public class CLIParser {
 
             List<Object> vals = values.get(longForm);
             if (null == vals) {
-                vals = new ArrayList<Object>(2);
+                vals = new ArrayList<>(2);
                 values.put(longForm, vals);
                 if (null != shortForm) {
                     values.put(shortForm, vals);
@@ -497,7 +470,7 @@ public class CLIParser {
     }
 
     private final void manualParse(final String[] args, final Locale locale) throws CLIIllegalOptionValueException, CLIUnknownOptionException {
-        final List<String> otherArgs = new ArrayList<String>(2);
+        final List<String> otherArgs = new ArrayList<>(2);
         int position = 0;
         while (position < args.length) {
             final String argument = args[position];
@@ -591,7 +564,7 @@ public class CLIParser {
 
         List<Object> vals = values.get(longForm);
         if (null == vals) {
-            vals = new ArrayList<Object>(2);
+            vals = new ArrayList<>(2);
             values.put(longForm, vals);
             final String shortForm = opt.shortForm();
             if (null != shortForm) {
