@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -360,7 +332,7 @@ public class StatisticTools extends AbstractJMXTools {
         }
         try {
             allocatedBytes = (long[]) mbc.invoke(srvThrdName, "getThreadAllocatedBytes", new Object[] { allThreadIds }, new String[] { "[J" });
-        } catch (javax.management.ReflectionException e) {
+        } catch (@SuppressWarnings("unused") javax.management.ReflectionException e) {
             System.err.println("AllocatedBytes is not supported on this JVM");
             // Simple set to an array of 0
             allocatedBytes = new long[threadInfo.length];
@@ -369,7 +341,7 @@ public class StatisticTools extends AbstractJMXTools {
         // First try the new method every time, if not available use the old iteration approach
         try {
             cpuTime = (long[]) mbc.invoke(srvThrdName, "getThreadCpuTime", new Object[] { allThreadIds }, new String[] { "[J" });
-        } catch (javax.management.ReflectionException e) {
+        } catch (@SuppressWarnings("unused") javax.management.ReflectionException e) {
             cpuTime = new long[threadInfo.length];
             for (int i = 0; i < allThreadIds.length; i++) {
                 cpuTime[i] = threadBean.getThreadCpuTime(allThreadIds[i]);
@@ -377,7 +349,7 @@ public class StatisticTools extends AbstractJMXTools {
         }
         try {
             userTime = (long[]) mbc.invoke(srvThrdName, "getThreadUserTime", new Object[] { allThreadIds }, new String[] { "[J" });
-        } catch (javax.management.ReflectionException e) {
+        } catch (@SuppressWarnings("unused") javax.management.ReflectionException e) {
             userTime = new long[threadInfo.length];
             for (int i = 0; i < allThreadIds.length; i++) {
                 userTime[i] = threadBean.getThreadUserTime(allThreadIds[i]);
@@ -387,7 +359,7 @@ public class StatisticTools extends AbstractJMXTools {
             System.err.println("Different results returned");
             return sb.toString();
         }
-        final ArrayList<ThreadOutputElem> arrayList = new ArrayList<ThreadOutputElem>();
+        final ArrayList<ThreadOutputElem> arrayList = new ArrayList<>();
         sb.append("ThreadID, Name, AllocatedBytes, CpuTime, UserTime");
         if (stacktrace) {
             sb.append(", StackTrace");
@@ -630,11 +602,10 @@ public class StatisticTools extends AbstractJMXTools {
      *
      * @param mbeanServerConnection The MBeanServerConnection to be used for querying MBeans.
      * @param out the {@link PrintStream} to write the output to.
-     * @throws IOException
      * @throws MalformedObjectNameException
      * @throws NullPointerException
      */
-    static String showGrizzlyData(final MBeanServerConnection mbeanServerConnection) throws MalformedObjectNameException, NullPointerException, IOException {
+    static String showGrizzlyData(final MBeanServerConnection mbeanServerConnection) throws MalformedObjectNameException, NullPointerException {
         StringBuilder sb = new StringBuilder();
         // Iterate over the MBeans we are interested in, query by objectName
         for (final GrizzlyMBean grizzlyMBean : GrizzlyMBean.values()) {
