@@ -1,54 +1,28 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
 package com.openexchange.admin.console.context;
 
+import static com.openexchange.java.Autoboxing.I;
+import static com.openexchange.java.Autoboxing.L;
 import java.text.ParseException;
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -56,6 +30,7 @@ import java.util.Collection;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Map;
+import java.util.Optional;
 import java.util.ServiceLoader;
 import com.openexchange.admin.console.AdminParser;
 import com.openexchange.admin.console.AdminParser.NeededQuadState;
@@ -76,6 +51,9 @@ import com.openexchange.tools.oxfolder.GABMode;
 
 public abstract class ContextAbstraction extends UserAbstraction {
 
+    protected static final Optional<String> dynamicAttrDesc = Optional.of("Allows to configure various context attributes");
+    protected static final Optional<String> dynamicRemoveAttrDesc = Optional.of("Allows to remove various context attributes");
+
     private interface ClosureInterface {
 
         public ArrayList<String> getData(final Context ctx);
@@ -168,7 +146,10 @@ public abstract class ContextAbstraction extends UserAbstraction {
     private final static char OPT_QUOTA_SHORT = 'q';
 
     private final static String OPT_QUOTA_LONG = "quota";
+
+    @SuppressWarnings("hiding")
     protected static final String OPT_NAME_ADMINPASS_DESCRIPTION = "master Admin password";
+    @SuppressWarnings("hiding")
     protected static final String OPT_NAME_ADMINUSER_DESCRIPTION = "master Admin user name";
 
     private final static String OPT_GAB_MODE = "gabMode";
@@ -213,7 +194,7 @@ public abstract class ContextAbstraction extends UserAbstraction {
     protected void parseAndSetContextQuota(final AdminParser parser, final Context ctx) {
         final String contextQuota = (String) parser.getOptionValue(this.contextQuotaOption);
         if (null != contextQuota) {
-            ctx.setMaxQuota(Long.parseLong(contextQuota));
+            ctx.setMaxQuota(L(Long.parseLong(contextQuota)));
         }
     }
 
@@ -285,7 +266,7 @@ public abstract class ContextAbstraction extends UserAbstraction {
     }
 
     protected void sysoutOutput(Context[] ctxs, boolean continuation, AdminParser parser) throws InvalidDataException {
-        final ArrayList<ArrayList<String>> data = new ArrayList<ArrayList<String>>();
+        final ArrayList<ArrayList<String>> data = new ArrayList<>();
         for (final Context ctx : ctxs) {
             data.add(makeData(ctx, new ClosureInterface() {
 
@@ -297,7 +278,7 @@ public abstract class ContextAbstraction extends UserAbstraction {
         }
 
         final ArrayList<String> humanReadableColumnsOfAllExtensions = getHumanReadableColumnsOfAllExtensions(parser);
-        final ArrayList<String> alignment = new ArrayList<String>();
+        final ArrayList<String> alignment = new ArrayList<>();
         alignment.add("r");
         alignment.add("r");
         alignment.add("l");
@@ -309,7 +290,7 @@ public abstract class ContextAbstraction extends UserAbstraction {
         for (int i = 0; i < humanReadableColumnsOfAllExtensions.size(); i++) {
             alignment.add("l");
         }
-        final ArrayList<String> columnnames = new ArrayList<String>();
+        final ArrayList<String> columnnames = new ArrayList<>();
         columnnames.add("cid");
         columnnames.add("fid");
         columnnames.add("fname");
@@ -324,9 +305,9 @@ public abstract class ContextAbstraction extends UserAbstraction {
     }
 
     protected void sysoutOutput(Quota[] quotas) throws InvalidDataException {
-        ArrayList<ArrayList<String>> data = new ArrayList<ArrayList<String>>();
+        ArrayList<ArrayList<String>> data = new ArrayList<>();
         for (Quota quota : quotas) {
-            ArrayList<String> curData = new ArrayList<String>(2);
+            ArrayList<String> curData = new ArrayList<>(2);
 
             {
                 String module = quota.getModule();
@@ -345,11 +326,11 @@ public abstract class ContextAbstraction extends UserAbstraction {
             data.add(curData);
         }
 
-        ArrayList<String> alignment = new ArrayList<String>();
+        ArrayList<String> alignment = new ArrayList<>();
         alignment.add("r");
         alignment.add("l");
 
-        ArrayList<String> columnnames = new ArrayList<String>();
+        ArrayList<String> columnnames = new ArrayList<>();
         columnnames.add("module");
         columnnames.add("qlimit");
 
@@ -362,7 +343,7 @@ public abstract class ContextAbstraction extends UserAbstraction {
 
     protected void precsvinfos(Context[] ctxs, boolean continuation, AdminParser parser) throws InvalidDataException {
         // needed for csv output, KEEP AN EYE ON ORDER!!!
-        final ArrayList<String> columns = new ArrayList<String>();
+        final ArrayList<String> columns = new ArrayList<>();
         columns.add("id");
         columns.add("filestore_id");
         columns.add("filestore_name");
@@ -373,7 +354,7 @@ public abstract class ContextAbstraction extends UserAbstraction {
         columns.add("lmappings");
         columns.add("attributes");
         columns.addAll(getCSVColumnsOfAllExtensions(parser));
-        final ArrayList<ArrayList<String>> data = new ArrayList<ArrayList<String>>();
+        final ArrayList<ArrayList<String>> data = new ArrayList<>();
 
         for (final Context ctx_tmp : ctxs) {
             data.add(makeData(ctx_tmp, new ClosureInterface() {
@@ -390,13 +371,13 @@ public abstract class ContextAbstraction extends UserAbstraction {
     }
 
     protected void precsvinfos(Quota[] quotas) throws InvalidDataException {
-        ArrayList<String> columns = new ArrayList<String>();
+        ArrayList<String> columns = new ArrayList<>();
         columns.add("module");
         columns.add("limit");
 
-        ArrayList<ArrayList<String>> data = new ArrayList<ArrayList<String>>();
+        ArrayList<ArrayList<String>> data = new ArrayList<>();
         for (Quota quota : quotas) {
-            ArrayList<String> curData = new ArrayList<String>(2);
+            ArrayList<String> curData = new ArrayList<>(2);
 
             {
                 String module = quota.getModule();
@@ -489,7 +470,7 @@ public abstract class ContextAbstraction extends UserAbstraction {
     protected void parseAndSetDatabaseID(final AdminParser parser, final Database db) {
         final String optionvalue = (String) parser.getOptionValue(this.databaseIdOption);
         if (null != optionvalue) {
-            dbid = Integer.parseInt(optionvalue);
+            dbid = I(Integer.parseInt(optionvalue));
             db.setId(dbid);
         }
     }
@@ -511,7 +492,7 @@ public abstract class ContextAbstraction extends UserAbstraction {
     }
 
     protected Filestore parseAndSetFilestoreId(final AdminParser parser) {
-        filestoreid = Integer.parseInt((String) parser.getOptionValue(this.targetFilestoreIDOption));
+        filestoreid = I(Integer.parseInt((String) parser.getOptionValue(this.targetFilestoreIDOption)));
         final Filestore fs = new Filestore(filestoreid);
         return fs;
     }
@@ -606,24 +587,50 @@ public abstract class ContextAbstraction extends UserAbstraction {
         return filestoreid;
     }
 
+    /**
+     * Returns all human readable columns of all extensions
+     * 
+     * @param parser The admin parser
+     * @return A list with all human readable columns
+     */
     protected ArrayList<String> getHumanReadableColumnsOfAllExtensions(final AdminParser parser) {
-        return new ArrayList<String>();
+        return new ArrayList<>();
     }
 
+    /**
+     * Returns all human readable data of all extensions
+     * 
+     * @param ctx The context
+     * @param parser The admin parser
+     * @return A list with all human readable data
+     */
     protected ArrayList<String> getHumanReableDataOfAllExtensions(final Context ctx, final AdminParser parser) {
-        return new ArrayList<String>();
+        return new ArrayList<>();
     }
 
+    /**
+     * Returns all CSV columns of all extensions
+     * 
+     * @param parser The admin parser
+     * @return A list with all CSV columns
+     */
     protected Collection<? extends String> getCSVColumnsOfAllExtensions(final AdminParser parser) {
-        return new ArrayList<String>();
+        return new ArrayList<>();
     }
 
-    protected ArrayList<String> getCSVDataOfAllExtensions(final Context ctx_tmp, final AdminParser parser) {
-        return new ArrayList<String>();
+    /**
+     * Returns all CSV data of all extensions
+     * 
+     * @param ctx The context
+     * @param parser The admin parser
+     * @return A list with all CSV data
+     */
+    protected ArrayList<String> getCSVDataOfAllExtensions(final Context ctx, final AdminParser parser) {
+        return new ArrayList<>();
     }
 
     private ArrayList<String> makeData(final Context ctx, final ClosureInterface iface, final boolean csv) {
-        final ArrayList<String> srv_data = new ArrayList<String>();
+        final ArrayList<String> srv_data = new ArrayList<>();
         srv_data.add(String.valueOf(ctx.getId()));
 
         final Integer filestoreId = ctx.getFilestoreId();
