@@ -1,54 +1,27 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
 package com.openexchange.admin.console.context;
 
+import static com.openexchange.java.Autoboxing.i;
 import java.net.MalformedURLException;
 import java.rmi.Naming;
 import java.rmi.NotBoundException;
@@ -73,15 +46,24 @@ public class Create extends CreateCore {
 
     private OXContextInterface csv_oxctx;
 
-    public Create(final String[] args2) {
-
-        final AdminParser parser = new AdminParser("createcontext");
-
-        commonfunctions(parser, args2);
+    /**
+     * Initializes a new {@link Change}.
+     */
+    public Create() {
+        super();
     }
 
     public static void main(final String args[]) {
-        new Create(args);
+        new Create().execute(args);
+    }
+
+    /**
+     * Executes the command
+     *
+     * @param args the command line arguments
+     */
+    public void execute(String[] args) {
+        commonfunctions(new AdminParser("createcontext"), args);
     }
 
     @Override
@@ -91,9 +73,6 @@ public class Create extends CreateCore {
         ctxabs.setDestinationStoreIdOption(parser, false);
         ctxabs.setDestinationDatabaseIdOption(parser, false);
 
-        setConfigOption(parser);
-        setRemoveConfigOption(parser);
-
         setAddAccessRightCombinationNameOption(parser);
         setModuleAccessOptions(parser);
 
@@ -103,7 +82,7 @@ public class Create extends CreateCore {
     @Override
     protected Context maincall(final AdminParser parser, final Context ctx, final User usr, final Credentials auth, SchemaSelectStrategy schemaSelectStrategy) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException, MalformedURLException, NotBoundException, ContextExistsException, NoSuchContextException {
         // get rmi ref
-        final OXContextInterface oxctx = (OXContextInterface) Naming.lookup(RMI_HOSTNAME + OXContextInterface.RMI_NAME);
+        OXContextInterface oxctx = OXContextInterface.class.cast(Naming.lookup(RMI_HOSTNAME + OXContextInterface.RMI_NAME));
 
         // add login mappings
         ctxabs.parseAndSetAddLoginMapping(parser);
@@ -112,9 +91,9 @@ public class Create extends CreateCore {
 
         ctxabs.changeMappingSetting(oxctx, ctx, auth, false);
         ctx.setFilestoreId(ctxabs.getStoreid());
-        final Integer db = ctxabs.getDatabaseid();
+        Integer db = ctxabs.getDatabaseid();
         if (null != db) {
-            ctx.setWriteDatabase(new Database(db));
+            ctx.setWriteDatabase(new Database(i(db)));
         }
 
         Context createdctx = null;
