@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -108,7 +80,7 @@ public abstract class ListCore extends UserAbstraction {
 
             if (null != parser.getOptionValue(this.csvOutputOption)) {
                 // map user data to corresponding module access
-                final HashMap<Integer, UserModuleAccess> usr2axs = new HashMap<Integer, UserModuleAccess>();
+                final HashMap<Integer, UserModuleAccess> usr2axs = new HashMap<>();
 
                 for (final User user : allusers) {
                     // fetch module access for every user
@@ -137,11 +109,11 @@ public abstract class ListCore extends UserAbstraction {
      * @throws InvalidDataException
      *
      */
-    @SuppressWarnings("unchecked")
+    @SuppressWarnings({ "unchecked", "deprecation" })
     protected void precsvinfos(final User[] users, final HashMap<Integer, UserModuleAccess> access_map) throws IllegalArgumentException, IllegalAccessException, InvocationTargetException, InvalidDataException {
         final Method[] methods = User.class.getMethods();
         // Filter out the old gui_spam_filter_enabled getters
-        final Map<String, String> notallowedOrReplace = new HashMap<String, String>();
+        final Map<String, String> notallowedOrReplace = new HashMap<>();
         notallowedOrReplace.put("GUI_Spam_filter_capabilities_enabled", "");
         notallowedOrReplace.put("Spam_filter_enabled", "");
         notallowedOrReplace.put("Gui_spam_filter_enabled", "GUI_Spam_filter_capabilities_enabled");
@@ -155,7 +127,7 @@ public abstract class ListCore extends UserAbstraction {
         notallowedOrReplace.put("SmtpPort", "");
         final ArrayList<MethodAndNames> methArrayList = getGetters(methods, notallowedOrReplace);
 
-        final ArrayList<String> columnnames = new ArrayList<String>(32);
+        final ArrayList<String> columnnames = new ArrayList<>(32);
         for (final MethodAndNames methodandnames : methArrayList) {
             columnnames.add(methodandnames.getName());
         }
@@ -192,9 +164,9 @@ public abstract class ListCore extends UserAbstraction {
             columnnames.add(UserAbstraction.OPT_ACCESS_PUBLIC_FOLDER_EDITABLE);
 
         }
-        final ArrayList<ArrayList<String>> data = new ArrayList<ArrayList<String>>();
+        final ArrayList<ArrayList<String>> data = new ArrayList<>();
         for (final User user : users) {
-            final ArrayList<String> datarow = new ArrayList<String>();
+            final ArrayList<String> datarow = new ArrayList<>();
             for (final MethodAndNames methodandnames : methArrayList) {
                 final String returntype = methodandnames.getReturntype();
                 if (returntype.equals(JAVA_LANG_STRING)) {
@@ -302,7 +274,7 @@ public abstract class ListCore extends UserAbstraction {
 
     protected final void sysoutOutput(final User[] users) throws InvalidDataException {
 
-        final ArrayList<ArrayList<String>> data = new ArrayList<ArrayList<String>>();
+        final ArrayList<ArrayList<String>> data = new ArrayList<>();
         for (final User user : users) {
             printExtensionsError(user);
             data.add(makeStandardData(user));
@@ -314,7 +286,7 @@ public abstract class ListCore extends UserAbstraction {
     }
 
     private ArrayList<String> makeStandardData(final User user) {
-        final ArrayList<String> res_data = new ArrayList<String>();
+        final ArrayList<String> res_data = new ArrayList<>();
 
         res_data.add(String.valueOf(user.getId()));// id
 
