@@ -1,51 +1,24 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
+
 package com.openexchange.admin.console.util.database;
 
 import java.rmi.Naming;
@@ -66,11 +39,10 @@ import com.openexchange.admin.rmi.dataobjects.Database;
  */
 public final class CreateSchemas extends DatabaseAbstraction {
 
-    public CreateSchemas(final String[] args2) {
+    public void execute(final String[] args2) {
         final AdminParser parser = new AdminParser("createschemas");
         setOptions(parser);
 
-        String successtext = null;
         try {
             parser.ownparse(args2);
 
@@ -84,11 +56,11 @@ public final class CreateSchemas extends DatabaseAbstraction {
             parseAndSetDatabasename(parser, db);
             parseAndSetNumberOfSchemas(parser);
 
-            successtext = nameOrIdSet(this.dbid, this.dbname, "database");
+            nameOrIdSet(this.dbid, this.dbname, "database");
 
             // Trigger creation of schemas
             final AtomicReference<String[]> createdSchemas = new AtomicReference<>(null);
-            final AtomicReference<Exception> errorRef = new AtomicReference<Exception>();
+            final AtomicReference<Exception> errorRef = new AtomicReference<>();
             Runnable runnbable = new Runnable() {
 
                 @Override
@@ -100,7 +72,7 @@ public final class CreateSchemas extends DatabaseAbstraction {
                     }
                 }
             };
-            FutureTask<Void> ft = new FutureTask<Void>(runnbable, null);
+            FutureTask<Void> ft = new FutureTask<>(runnbable, null);
             new Thread(ft, "Open-Xchange Database Schema Creator").start();
 
             // Await termination
@@ -112,7 +84,7 @@ public final class CreateSchemas extends DatabaseAbstraction {
                 if (1 == numSchemas) {
                     infoMessage = "Creating 1 schema in database " + (null == dbid ? dbname : dbid) + ". This may take a while";
                 } else {
-                    infoMessage = "Creating "+numSchemas+" schemas in database " + (null == dbid ? dbname : dbid) + ". This may take a while";
+                    infoMessage = "Creating " + numSchemas + " schemas in database " + (null == dbid ? dbname : dbid) + ". This may take a while";
                 }
             }
             System.out.print(infoMessage);
@@ -151,7 +123,7 @@ public final class CreateSchemas extends DatabaseAbstraction {
     }
 
     public static void main(final String args[]) {
-        new CreateSchemas(args);
+        new CreateSchemas().execute(args);
     }
 
     private void setOptions(final AdminParser parser) {
