@@ -1,54 +1,27 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
 package com.openexchange.admin.console.util.database;
 
+import static com.openexchange.java.Autoboxing.I;
 import java.io.IOException;
 import java.net.MalformedURLException;
 import java.rmi.Naming;
@@ -72,10 +45,10 @@ import javax.management.remote.JMXConnectorFactory;
 import javax.management.remote.JMXServiceURL;
 import com.openexchange.admin.console.AdminParser;
 import com.openexchange.admin.console.AdminParser.NeededQuadState;
-import com.openexchange.admin.plugin.hosting.exceptions.TargetDatabaseException;
-import com.openexchange.admin.plugin.hosting.schemamove.mbean.SchemaMoveRemote;
 import com.openexchange.admin.console.CLIOption;
 import com.openexchange.admin.console.ObjectNamingAbstraction;
+import com.openexchange.admin.plugin.hosting.exceptions.TargetDatabaseException;
+import com.openexchange.admin.plugin.hosting.schemamove.mbean.SchemaMoveRemote;
 import com.openexchange.admin.rmi.OXUtilInterface;
 import com.openexchange.admin.rmi.dataobjects.Credentials;
 import com.openexchange.admin.rmi.dataobjects.Database;
@@ -211,7 +184,7 @@ public class UpgradeSchemata extends ObjectNamingAbstraction {
                     throw e;
                 }
                 System.out.println("The schema '" + schemaName + "' is empty. Skipping.");
-            } catch (NoSuchObjectException e) {
+            } catch (@SuppressWarnings("unused") NoSuchObjectException e) {
                 System.out.println("Schema " + schemaName + " not found. Skipping");
             } finally {
                 if (!force && error) {
@@ -238,8 +211,8 @@ public class UpgradeSchemata extends ObjectNamingAbstraction {
 
         // Sort arithmetically, that is by integer suffix of each database schema
         Comparator<Database> comparator = (o1, o2) -> {
-            Integer i1 = Integer.parseInt(o1.getScheme().substring(o1.getScheme().lastIndexOf('_') + 1));
-            Integer i2 = Integer.parseInt(o2.getScheme().substring(o2.getScheme().lastIndexOf('_') + 1));
+            Integer i1 = I(Integer.parseInt(o1.getScheme().substring(o1.getScheme().lastIndexOf('_') + 1)));
+            Integer i2 = I(Integer.parseInt(o2.getScheme().substring(o2.getScheme().lastIndexOf('_') + 1)));
             return i1.compareTo(i2);
         };
         Arrays.sort(databases, comparator);
@@ -268,7 +241,7 @@ public class UpgradeSchemata extends ObjectNamingAbstraction {
             int position = Arrays.binarySearch(databases, new Database(-1, schema), comparator);
             if (position >= 0) {
                 // Remember database position to be skipped
-                indexesToSkip.add(position);
+                indexesToSkip.add(I(position));
             }
         }
 
@@ -416,6 +389,7 @@ public class UpgradeSchemata extends ObjectNamingAbstraction {
                 case ABORT:
                     System.out.println("OK, aborting upgrade");
                     sysexit(0);
+                    return;
                 case CONTINUE:
                     scanner.close();
                     System.out.println("OK, proceeding with the upgrade");
@@ -455,7 +429,7 @@ public class UpgradeSchemata extends ObjectNamingAbstraction {
         if (jmxUsername == null || jmxPassword == null) {
             environment = null;
         } else {
-            environment = new HashMap<String, Object>(1);
+            environment = new HashMap<>(1);
             String[] creds = new String[] { jmxUsername, jmxPassword };
             environment.put(JMXConnector.CREDENTIALS, creds);
         }
@@ -471,7 +445,7 @@ public class UpgradeSchemata extends ObjectNamingAbstraction {
      * @param parser The {@link AdminParser}
      * @throws InvalidCredentialsException
      */
-    private void checkAndSetArguments(AdminParser parser) throws InvalidCredentialsException {
+    private void checkAndSetArguments(AdminParser parser) {
         // Parse the server name
         String serverName = (String) parser.getOptionValue(serverNameOption);
         server = new Server();
@@ -534,7 +508,7 @@ public class UpgradeSchemata extends ObjectNamingAbstraction {
         }
         try {
             port = Integer.parseInt(value.trim());
-        } catch (NumberFormatException e) {
+        } catch (@SuppressWarnings("unused") NumberFormatException e) {
             System.err.println("Port parameter is not a number: " + value);
             parser.printUsage();
             System.exit(1);
