@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -51,6 +23,7 @@ package com.openexchange.admin.plugin.hosting.rmi.impl;
 
 import static com.openexchange.java.Autoboxing.I;
 import static com.openexchange.java.Autoboxing.I2i;
+import static com.openexchange.java.Autoboxing.i;
 import static com.openexchange.java.Autoboxing.i2I;
 import java.net.URI;
 import java.net.URISyntaxException;
@@ -66,6 +39,8 @@ import java.util.Optional;
 import java.util.Set;
 import java.util.concurrent.ExecutionException;
 import java.util.regex.Pattern;
+import java.util.stream.Collectors;
+import java.util.stream.Stream;
 import com.openexchange.admin.daemons.ClientAdminThread;
 import com.openexchange.admin.daemons.ClientAdminThreadExtended;
 import com.openexchange.admin.plugin.hosting.services.AdminServiceRegistry;
@@ -110,14 +85,18 @@ import com.openexchange.admin.tools.AdminCache;
 import com.openexchange.admin.tools.filestore.FilestoreDataMover;
 import com.openexchange.admin.tools.filestore.PostProcessTask;
 import com.openexchange.caching.Cache;
+import com.openexchange.caching.CacheKey;
 import com.openexchange.caching.CacheService;
 import com.openexchange.config.cascade.ConfigProperty;
 import com.openexchange.config.cascade.ConfigView;
 import com.openexchange.config.cascade.ConfigViewFactory;
+import com.openexchange.config.cascade.ConfigViewScope;
 import com.openexchange.exception.LogLevel;
 import com.openexchange.exception.OXException;
 import com.openexchange.filestore.FileStorages;
+import com.openexchange.groupware.contexts.impl.ContextImpl;
 import com.openexchange.groupware.contexts.impl.ContextStorage;
+import com.openexchange.groupware.userconfiguration.UserConfigurationStorage;
 import com.openexchange.java.Strings;
 import com.openexchange.tools.pipesnfilters.Filter;
 
@@ -520,15 +499,25 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                     for (final OXContextPluginInterface oxContextPlugin : plugins) {
                         if (oxContextPlugin instanceof OXContextPluginInterfaceExtended) {
                             OXContextPluginInterfaceExtended extended = (OXContextPluginInterfaceExtended) oxContextPlugin;
-                            Map<String, Object> undoInfo = extended.undoableDelete(ctx, auth);
-                            if (undoInfo != null) {
-                                if (undeleteInfos == null) {
-                                    undeleteInfos = new LinkedHashMap<OXContextPluginInterfaceExtended, Map<String, Object>>(plugins.size());
+                            try {
+                                Map<String, Object> undoInfo = extended.undoableDelete(ctx, auth);
+                                if (undoInfo != null) {
+                                    if (undeleteInfos == null) {
+                                        undeleteInfos = new LinkedHashMap<OXContextPluginInterfaceExtended, Map<String, Object>>(plugins.size());
+                                    }
+                                    undeleteInfos.put(extended, undoInfo);
                                 }
-                                undeleteInfos.put(extended, undoInfo);
+                            } catch (PluginException e) {
+                                undoDelete(ctx, undeleteInfos);
+                                throw e;
                             }
                         } else {
-                            oxContextPlugin.delete(ctx, auth);
+                            try {
+                                oxContextPlugin.delete(ctx, auth);
+                            } catch (PluginException e) {
+                                undoDelete(ctx, undeleteInfos);
+                                throw e;
+                            }
                         }
                     }
                 }
@@ -543,14 +532,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                     deleted = true;
                 } finally {
                     if (!deleted) {
-                        for (Map.Entry<OXContextPluginInterfaceExtended, Map<String, Object>> undeleteInfo : undeleteInfos.entrySet()) {
-                            try {
-                                Map<String, Object> undoInfo = undeleteInfo.getValue();
-                                undeleteInfo.getKey().undelete(ctx, undoInfo);
-                            } catch (PluginException x) {
-                                log(LogLevel.WARNING, LOGGER, credentials, ctx.getIdAsString(), x, "Undeletion failed");
-                            }
-                        }
+                        undoDelete(ctx, undeleteInfos);
                     }
                 }
             }
@@ -564,6 +546,26 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         }
     }
 
+    /**
+     * Performs an undo
+     *
+     * @param ctx The context
+     * @param undeleteInformation The undelete information
+     */
+    private void undoDelete(final Context ctx, Map<OXContextPluginInterfaceExtended, Map<String, Object>> undeleteInformation) {
+        if (undeleteInformation == null) {
+            return;
+        }
+        for (Map.Entry<OXContextPluginInterfaceExtended, Map<String, Object>> undeleteInfo : undeleteInformation.entrySet()) {
+            try {
+                Map<String, Object> undoInfo = undeleteInfo.getValue();
+                undeleteInfo.getKey().undelete(ctx, undoInfo);
+            } catch (PluginException x) {
+                LOGGER.warn("Undeletion failed", x);
+            }
+        }
+    }
+
     @Override
     public void disable(final Context ctx, final Credentials auth) throws RemoteException, InvalidCredentialsException, NoSuchContextException, StorageException, InvalidDataException, NoSuchReasonException, OXContextException {
         final MaintenanceReason reason = new MaintenanceReason(Integer.valueOf(42));
@@ -1215,7 +1217,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                 view = viewFactory.getView(admin_user.getId().intValue(), ret.getId().intValue());
                 Boolean check = view.opt("com.openexchange.imap.initWithSpecialUse", Boolean.class, Boolean.TRUE);
                 if (check != null && check.booleanValue()) {
-                    ConfigProperty<Boolean> prop = view.property("user", "com.openexchange.mail.specialuse.check", Boolean.class);
+                    ConfigProperty<Boolean> prop = view.property(ConfigViewScope.USER.getScopeName(), "com.openexchange.mail.specialuse.check", Boolean.class);
                     prop.set(Boolean.TRUE);
                 }
             } catch (OXException e) {
@@ -1338,6 +1340,9 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             throw e3;
         }
 
+        OXUserStorageInterface oxu;
+        Integer[] userIds;
+        int adminId;
         try {
             BasicAuthenticator.createPluginAwareAuthenticator().doAuthentication(auth);
 
@@ -1373,11 +1378,11 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                 }
             }
 
-            final OXUserStorageInterface oxu = OXUserStorageInterface.getInstance();
+            oxu = OXUserStorageInterface.getInstance();
 
             // change rights for all users in context to specified one in access combination name
-            Integer[] userIds = i2I(oxu.getAll(ctx));
-            final int adminId = tool.getAdminForContext(ctx);
+            userIds = i2I(oxu.getAll(ctx));
+            adminId = tool.getAdminForContext(ctx);
             userIds = com.openexchange.tools.arrays.Arrays.remove(userIds, I(adminId));
             oxu.changeModuleAccess(ctx, adminId, accessAdmin);
             oxu.changeModuleAccess(ctx, I2i(userIds), accessUser);
@@ -1387,6 +1392,51 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             logAndEnhanceException(e, credentials, ctx);
             throw e;
         }
+
+        // JCS
+        Set<Integer> distinctUserIds = Stream.concat(Stream.of(Integer.valueOf(adminId)), Arrays.stream(userIds)).collect(Collectors.toSet());
+        for (Integer userId : distinctUserIds) {
+            try {
+                UserConfigurationStorage.getInstance().invalidateCache(userId.intValue(), new ContextImpl(ctx.getId().intValue()));
+            } catch (OXException e) {
+                log(LogLevel.ERROR, LOGGER, credentials, ctx.getIdAsString(), String.valueOf(userId), e, "Error removing user {} in context {} from configuration storage", userId, ctx.getId());
+            } catch (RuntimeException e) {
+                log(LogLevel.ERROR, LOGGER, credentials, ctx.getIdAsString(), String.valueOf(userId), e, "");
+            }
+
+            final CacheService cacheService = AdminServiceRegistry.getInstance().getService(CacheService.class);
+            if (null != cacheService) {
+                try {
+                    final Cache usercCache = cacheService.getCache("User");
+                    final Cache upCache = cacheService.getCache("UserPermissionBits");
+                    final Cache ucCache = cacheService.getCache("UserConfiguration");
+                    final Cache usmCache = cacheService.getCache("UserSettingMail");
+                    final Cache capabilitiesCache = cacheService.getCache("Capabilities");
+                    {
+                        final CacheKey key = cacheService.newCacheKey(i(ctx.getId()), userId.intValue());
+                        usercCache.remove(key);
+                        try {
+                            User[] usrdata = oxu.getData(ctx, new User[] { new User(userId.intValue()) });
+                            usercCache.remove(cacheService.newCacheKey(i(ctx.getId()), usrdata[0].getName()));
+                        } catch (Exception x) {
+                            log(LogLevel.ERROR, LOGGER, credentials, ctx.getIdAsString(), String.valueOf(userId), x, "Error loading user {} in context {}", userId, ctx.getId());
+                        }
+                        upCache.remove(key);
+                        ucCache.remove(key);
+                        usmCache.remove(key);
+                        capabilitiesCache.removeFromGroup(userId, ctx.getId().toString());
+                        try {
+                            UserConfigurationStorage.getInstance().invalidateCache(userId.intValue(), new ContextImpl(ctx.getId().intValue()));
+                        } catch (OXException e) {
+                            log(LogLevel.ERROR, LOGGER, credentials, ctx.getIdAsString(), String.valueOf(userId), e, "Error removing user {} in context {} from configuration storage", userId, ctx.getId());
+                        }
+                    }
+                } catch (Exception e) {
+                    log(LogLevel.ERROR, LOGGER, credentials, ctx.getIdAsString(), String.valueOf(userId), e, "");
+                }
+            }
+        }
+        // END OF JCS
     }
 
     /**
