@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -51,11 +23,15 @@ package com.openexchange.admin.rmi.impl;
 
 import static com.openexchange.java.Autoboxing.I;
 import static com.openexchange.java.Autoboxing.i;
+import java.rmi.RemoteException;
+import java.util.HashMap;
 import java.util.Map;
 import java.util.Optional;
 import java.util.Set;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
+import org.slf4j.Logger;
+import com.google.common.collect.ImmutableMap;
 import com.openexchange.admin.rmi.dataobjects.Context;
 import com.openexchange.admin.rmi.dataobjects.Credentials;
 import com.openexchange.admin.rmi.dataobjects.Database;
@@ -73,18 +49,20 @@ import com.openexchange.admin.rmi.exceptions.NoSuchGroupException;
 import com.openexchange.admin.rmi.exceptions.NoSuchObjectException;
 import com.openexchange.admin.rmi.exceptions.NoSuchResourceException;
 import com.openexchange.admin.rmi.exceptions.NoSuchUserException;
+import com.openexchange.admin.rmi.exceptions.RemoteExceptionUtils;
 import com.openexchange.admin.rmi.exceptions.StorageException;
 import com.openexchange.admin.services.AdminServiceRegistry;
 import com.openexchange.admin.storage.interfaces.OXToolStorageInterface;
 import com.openexchange.exception.LogLevel;
-import com.openexchange.log.LogProperties;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.userconfiguration.PermissionConfigurationChecker;
+import com.openexchange.log.LogProperties;
 
 /**
- * General abstraction class used by all impl classes
+ * {@link OXCommonImpl} - General abstraction class used by all impl classes
  *
  * @author d7
+ * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
  */
 public abstract class OXCommonImpl {
 
@@ -94,9 +72,18 @@ public abstract class OXCommonImpl {
 
     protected final OXToolStorageInterface tool;
 
+    private static final Map<Class<?>, ExceptionHandler> exceptionHandlers;
+    static {
+        Map<Class<?>, ExceptionHandler> eh = new HashMap<>();
+        eh.put(AbstractAdminRmiException.class, (t, credentials) -> logAndReturnException(LOGGER, ((AbstractAdminRmiException) t), credentials));
+        eh.put(RemoteException.class, (t, credentials) -> enhanceException(credentials, (RemoteException) t));
+        eh.put(Exception.class, (t, credentials) -> enhanceException(credentials, RemoteExceptionUtils.convertException((Exception) t)));
+        exceptionHandlers = ImmutableMap.copyOf(eh);
+    }
+
     /**
      * Initializes a new {@link OXCommonImpl}.
-
+     * 
      * @throws StorageException In case the PermissionConfigurationChecker service is unavailable
      */
     public OXCommonImpl() {
@@ -228,19 +215,39 @@ public abstract class OXCommonImpl {
     }
 
     /**
-     * @param objects
-     * @throws InvalidDataException
+     * Performs a null check and throws an exception if any of the passed objects is <code>null</code>
+     *
+     * @param objects The objects to perform the null check
+     * @throws InvalidDataException if any of the passed objects is <code>null</code>
      */
-    protected final static void doNullCheck(final Object... objects) throws InvalidDataException {
-        for (final Object object : objects) {
+    protected static void doNullCheck(Object... objects) throws InvalidDataException {
+        for (Object object : objects) {
             if (object == null) {
                 throw new InvalidDataException();
             }
         }
     }
 
+    /**
+     * Performs a null check and logs any exceptions before throwing
+     *
+     * @param logger The logger to log the exceptions
+     * @param credentials The credentials
+     * @param objects The objects to perform the null check
+     * @throws InvalidDataException if any of the passed objects is <code>null</code>
+     */
+    protected static void doNullCheck(Logger logger, Credentials credentials, Object... objects) throws InvalidDataException {
+        try {
+            doNullCheck(objects);
+        } catch (InvalidDataException e) {
+            log(LogLevel.ERROR, logger, credentials, e, "Invalid data sent by client!");
+            throw e;
+        }
+    }
+
     /**
      * Checks whether the context exists and updates the schema if needed
+     * 
      * @param ctx
      * @throws StorageException
      * @throws com.openexchange.admin.rmi.exceptions.DatabaseUpdateException
@@ -361,6 +368,33 @@ public abstract class OXCommonImpl {
         return logAndReturnException(logger, e, exceptionId, creds, null, null);
     }
 
+    /**
+     * Enhances and logs the specified {@link Throwable}
+     *
+     * @param t the {@link Throwable} to enhance and log
+     * @param credentials The credentials
+     */
+    protected static void enhanceAndLogException(Throwable t, Credentials credentials) {
+        ExceptionHandler exceptionHandler = exceptionHandlers.get(t.getClass().getSuperclass());
+        if (exceptionHandler == null) {
+            LOGGER.error("", t);
+            return;
+        }
+        exceptionHandler.handle(t, credentials);
+    }
+
+    /**
+     * Enhances the specified remote exception with the admin name and logs it
+     *
+     * @param credentials The credentials
+     * @param remoteException The remote exception to enhance
+     */
+    private static void enhanceException(Credentials credentials, RemoteException remoteException) {
+        String exceptionId = AbstractAdminRmiException.generateExceptionId();
+        RemoteExceptionUtils.enhanceRemoteException(remoteException, exceptionId);
+        logAndReturnException(LOGGER, remoteException, exceptionId, credentials);
+    }
+
     // -------------------------------------------------------------------------------------------------------------------------------------
 
     /**
@@ -493,4 +527,18 @@ public abstract class OXCommonImpl {
         log(level, logger, creds, null, null, e, message, new Object[] {});
     }
 
+    /**
+     * {@link ExceptionHandler}
+     */
+    @FunctionalInterface
+    private interface ExceptionHandler {
+
+        /**
+         * Handles the specified {@link Throwable}
+         *
+         * @param t The {@link Throwable} to handle
+         * @param credentials The credentials to optionally decorate the exception with the admin name
+         */
+        void handle(Throwable t, Credentials credentials);
+    }
 }
