@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -51,6 +23,7 @@ package com.openexchange.admin.rmi.impl;
 
 import static com.openexchange.java.Autoboxing.I;
 import static com.openexchange.java.Autoboxing.I2i;
+import static com.openexchange.java.Autoboxing.i;
 import java.rmi.RemoteException;
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -380,7 +353,7 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
 
             final int retval = oxGroup.create(ctx, grp);
             grp.setId(I(retval));
-            final List<OXGroupPluginInterface> interfacelist = new ArrayList<OXGroupPluginInterface>();
+            final List<OXGroupPluginInterface> interfacelist = new ArrayList<>();
 
             // Trigger plugin extensions
             {
@@ -424,7 +397,7 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
                         int contextId = ctx.getId().intValue();
                         for (final Integer member_id : mems) {
                             cache.remove(cacheService.newCacheKey(contextId, member_id.intValue()));
-                            UserConfigurationStorage.getInstance().invalidateCache(member_id, new ContextImpl(ctx.getId().intValue()));
+                            UserConfigurationStorage.getInstance().invalidateCache(i(member_id), new ContextImpl(ctx.getId().intValue()));
                         }
 
                         Cache groupCache = cacheService.getCache(GroupService.CACHE_REGION_NAME);
@@ -514,7 +487,7 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
                 throw new NoSuchGroupException("No such group");
             }
 
-            final ArrayList<OXGroupPluginInterface> interfacelist = new ArrayList<OXGroupPluginInterface>();
+            final ArrayList<OXGroupPluginInterface> interfacelist = new ArrayList<>();
 
             // Trigger plugin extensions
             {
@@ -535,7 +508,7 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
             }
 
             // remember the old members for later cache invalidation
-            List<User[]> del_groups_members = new ArrayList<User[]>();
+            List<User[]> del_groups_members = new ArrayList<>();
             for (Group del_group : grp) {
                 del_groups_members.add(oxGroup.getMembers(ctx, del_group.getId().intValue()));
             }
@@ -671,7 +644,7 @@ public class OXGroup extends OXCommonImpl implements OXGroupInterface {
                 throw e;
             }
 
-            List<Group> retval = new ArrayList<Group>(groups.length);
+            List<Group> retval = new ArrayList<>(groups.length);
             for (final Group group : groups) {
                 retval.add(oxGroup.get(ctx, group));
             }
