@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -57,6 +29,7 @@ import com.openexchange.admin.daemons.ClientAdminThread;
 import com.openexchange.admin.plugins.OXResourcePluginInterface;
 import com.openexchange.admin.plugins.PluginException;
 import com.openexchange.admin.properties.AdminProperties;
+import com.openexchange.admin.properties.PropertyScope;
 import com.openexchange.admin.rmi.OXResourceInterface;
 import com.openexchange.admin.rmi.dataobjects.Context;
 import com.openexchange.admin.rmi.dataobjects.Credentials;
@@ -179,7 +152,7 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface {
             }
 
             final String resmail = res.getEmail();
-            if (resmail != null && resmail.trim().length() > 0 && !GenericChecks.isValidMailAddress(resmail)) {
+            if (resmail != null && resmail.trim().length() > 0 && (!GenericChecks.isValidMailAddress(resmail) || !GenericChecks.isValidMailAddress(resmail, PropertyScope.propertyScopeForContext(ctx.getId().intValue())))) {
                 throw new InvalidDataException("Invalid email address");
             }
             oxRes.change(ctx, res);
@@ -253,13 +226,13 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface {
             }
 
             final String resmail = res.getEmail();
-            if (resmail != null && !GenericChecks.isValidMailAddress(resmail)) {
+            if (resmail != null && (!GenericChecks.isValidMailAddress(resmail)) || !GenericChecks.isValidMailAddress(resmail, PropertyScope.propertyScopeForContext(ctx.getId().intValue()))) {
                 throw new InvalidDataException("Invalid email address");
             }
             final int retval = oxRes.create(ctx, res);
             res.setId(I(retval));
 
-            final ArrayList<OXResourcePluginInterface> interfacelist = new ArrayList<OXResourcePluginInterface>();
+            final ArrayList<OXResourcePluginInterface> interfacelist = new ArrayList<>();
 
             // Trigger plugin extensions
             {
@@ -330,7 +303,7 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface {
             if (!tool.existsResource(ctx, res.getId().intValue())) {
                 throw new NoSuchResourceException("Resource with this id does not exist");
             }
-            final ArrayList<OXResourcePluginInterface> interfacelist = new ArrayList<OXResourcePluginInterface>();
+            final ArrayList<OXResourcePluginInterface> interfacelist = new ArrayList<>();
 
             // Trigger plugin extensions
             {
@@ -452,7 +425,7 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface {
                     resource.setId(I(tool.getResourceIDByResourcename(ctx, resource.getName())));
                 }
             }
-            final ArrayList<Resource> retval = new ArrayList<Resource>();
+            final ArrayList<Resource> retval = new ArrayList<>();
             for (final Resource resource : resources) {
                 // not nice, but works ;)
                 final Resource tmp = oxRes.getData(ctx, resource);
