@@ -1,51 +1,23 @@
 /*
-*
-*    OPEN-XCHANGE legal information
-*
-*    All intellectual property rights in the Software are protected by
-*    international copyright laws.
-*
-*
-*    In some countries OX, OX Open-Xchange, open xchange and OXtender
-*    as well as the corresponding Logos OX Open-Xchange and OX are registered
-*    trademarks of the OX Software GmbH group of companies.
-*    The use of the Logos is not covered by the GNU General Public License.
-*    Instead, you are allowed to use these Logos according to the terms and
-*    conditions of the Creative Commons License, Version 2.5, Attribution,
-*    Non-commercial, ShareAlike, and the interpretation of the term
-*    Non-commercial applicable to the aforementioned license is published
-*    on the web site http://www.open-xchange.com/EN/legal/index.html.
-*
-*    Please make sure that third-party modules and libraries are used
-*    according to their respective licenses.
-*
-*    Any modifications to this package must retain all copyright notices
-*    of the original copyright holder(s) for the original code used.
-*
-*    After any such modifications, the original and derivative code shall remain
-*    under the copyright of the copyright holder(s) and/or original author(s)per
-*    the Attribution and Assignment Agreement that can be located at
-*    http://www.open-xchange.com/EN/developer/. The contributing author shall be
-*    given Attribution for the derivative code and a license granting use.
-*
-*     Copyright (C) 2016-2020 OX Software GmbH
-*     Mail: info@open-xchange.com
-*
-*
-*     This program is free software; you can redistribute it and/or modify it
-*     under the terms of the GNU General Public License, Version 2 as published
-*     by the Free Software Foundation.
-*
-*     This program is distributed in the hope that it will be useful, but
-*     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-*     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
-*     for more details.
-*
-*     You should have received a copy of the GNU General Public License along
-*     with this program; if not, write to the Free Software Foundation, Inc., 59
-*     Temple Place, Suite 330, Boston, MA 02111-1307 USA
-*
-*/
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
+ *
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
+ *
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
+ *
+ */
 
 package com.openexchange.admin.tools;
 
@@ -87,7 +59,9 @@ import com.openexchange.admin.rmi.exceptions.StorageException;
 import com.openexchange.admin.services.AdminServiceRegistry;
 import com.openexchange.admin.storage.sqlStorage.OXAdminPoolDBPool;
 import com.openexchange.admin.storage.sqlStorage.OXAdminPoolInterface;
+import com.openexchange.caching.CacheService;
 import com.openexchange.config.ConfigurationService;
+import com.openexchange.config.ConfigurationServices;
 import com.openexchange.database.Databases;
 import com.openexchange.database.JdbcProperties;
 import com.openexchange.exception.OXException;
@@ -102,7 +76,7 @@ import com.openexchange.tools.sql.DBUtils;
  */
 public class AdminCache {
 
-    private static final AtomicReference<BundleContext> BUNDLE_CONTEXT = new AtomicReference<BundleContext>();
+    private static final AtomicReference<BundleContext> BUNDLE_CONTEXT = new AtomicReference<>();
 
     /**
      * Gets the <tt>BundleContext</tt>.
@@ -133,7 +107,8 @@ public class AdminCache {
         BUNDLE_CONTEXT.set(service);
     }
 
-    private static final AtomicReference<ConfigurationService> CONF_SERVICE = new AtomicReference<ConfigurationService>();
+    private static final AtomicReference<ConfigurationService> CONF_SERVICE = new AtomicReference<>();
+    private static final AtomicReference<CacheService> CACHE_SERVICE = new AtomicReference<>();
 
     /**
      * Gets the <tt>ConfigurationService</tt>.
@@ -164,6 +139,35 @@ public class AdminCache {
         CONF_SERVICE.set(service);
     }
 
+    /**
+     * Gets the <tt>CacheService</tt>.
+     *
+     * @return The <tt>CacheService</tt> or <code>null</code>
+     */
+    public static CacheService getCacheService() {
+        return CACHE_SERVICE.get();
+    }
+
+    /**
+     * Atomically sets the <tt>CacheService</tt> to the given updated <tt>CacheService</tt> reference if the current value <tt>==</tt> the expected value.
+     *
+     * @param expect the expected <tt>CacheService</tt>
+     * @param update the new <tt>CacheService</tt>
+     * @return <code>true</code> if successful. <code>false</code> return indicates that the actual <tt>CacheService</tt> was not equal to the expected <tt>CacheService</tt>.
+     */
+    public static boolean compareAndSetCacheService(CacheService expect, CacheService update) {
+        return CACHE_SERVICE.compareAndSet(expect, update);
+    }
+
+    /**
+     * Sets the <tt>CacheService</tt>.
+     *
+     * @param service The <tt>CacheService</tt> to set
+     */
+    public static void setCacheService(CacheService service) {
+        CACHE_SERVICE.set(service);
+    }
+
     public final static String DATA_TRUNCATION_ERROR_MSG = "Data too long for column(s)";
 
     private PropertyHandler prop = null;
@@ -219,8 +223,8 @@ public class AdminCache {
         readAndSetMasterCredentials(service);
         log.info("Init Cache");
         initPool();
-        this.adminCredentialsCache = new Hashtable<Integer, Credentials>();
-        this.adminAuthMechCache = new Hashtable<Integer, String>();
+        this.adminCredentialsCache = new Hashtable<>();
+        this.adminAuthMechCache = new Hashtable<>();
     }
 
     /**
@@ -309,7 +313,7 @@ public class AdminCache {
     }
 
     private HashMap<String, UserModuleAccess> getAccessCombinations(HashMap<String, Method> module_method_mapping, Properties access_props) throws OXGenericException {
-        HashMap<String, UserModuleAccess> combis = new HashMap<String, UserModuleAccess>();
+        HashMap<String, UserModuleAccess> combis = new HashMap<>();
         // Now check if predefined combinations are valid
         Enumeration<Object> predefined_access_combinations = access_props.keys();
         while (predefined_access_combinations.hasMoreElements()) {
@@ -354,7 +358,7 @@ public class AdminCache {
     private HashMap<String, Method> loadValidAccessModules() throws ClassNotFoundException {
 
         // If we wanna blacklist some still unused modules, add them here!
-        HashSet<String> BLACKLIST = new HashSet<String>();
+        HashSet<String> BLACKLIST = new HashSet<>();
         // BLACKLIST.add("");
 
         try {
@@ -363,7 +367,7 @@ public class AdminCache {
             // usermoduleaccess object
             Class<?> tmp = Class.forName(UserModuleAccess.class.getCanonicalName());
             Method methlist[] = tmp.getDeclaredMethods();
-            HashMap<String, Method> module_method_mapping = new HashMap<String, Method>();
+            HashMap<String, Method> module_method_mapping = new HashMap<>();
 
             log.debug("Listing available modules for use in access combinations...");
             for (Method method : methlist) {
@@ -385,13 +389,17 @@ public class AdminCache {
         }
     }
 
-    private static Properties loadAccessCombinations() {
+    private static Properties loadAccessCombinations() throws OXGenericException {
         // Load properties from file , if does not exists use fall-back properties!
         ConfigurationService service = AdminServiceRegistry.getInstance().getService(ConfigurationService.class);
         if (null == service) {
             throw new IllegalStateException("Absent service: " + ConfigurationService.class.getName());
         }
-        return service.getFile("ModuleAccessDefinitions.properties");
+        try {
+            return ConfigurationServices.loadPropertiesFrom(service.getFileByName("ModuleAccessDefinitions.properties"));
+        } catch (IOException e) {
+            throw new OXGenericException("ModuleAccessDefinitions.properties file cannot be opened for reading!", e);
+        }
     }
 
     protected void initPool() {
@@ -869,7 +877,17 @@ public class AdminCache {
     }
 
     public boolean isMasterAdmin(Credentials auth) {
-        return masterAuthenticationDisabled || (getMasterCredentials() != null && getMasterCredentials().getLogin().equals(auth.getLogin()));
+        return isMasterAdmin(auth, true);
+    }
+
+    public boolean isMasterAdmin(Credentials auth, boolean considerMasterAuthenticationDisabled) {
+        if (considerMasterAuthenticationDisabled && masterAuthenticationDisabled) {
+            // Considered as master since master authentication is disabled.
+            return true;
+        }
+
+        Credentials masterCredentials = getMasterCredentials();
+        return masterCredentials != null && masterCredentials.getLogin().equals(auth.getLogin());
     }
 
     /**
@@ -899,23 +917,4 @@ public class AdminCache {
     public boolean isAllowMasterOverride() {
         return allowMasterOverride;
     }
-
-//    /**
-//     * {@link Encrypter} - Password encrypter interface
-//     *
-//     * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
-//     * @since v7.10.0
-//     */
-//    private interface Encrypter {
-//
-//        /**
-//         * Encrypts the specified password and returns it
-//         *
-//         * @param password The password to encrypt
-//         * @return The encrypted password
-//         * @throws UnsupportedEncodingException
-//         * @throws NoSuchAlgorithmException
-//         */
-//        String encrypt(String password) throws UnsupportedEncodingException, NoSuchAlgorithmException;
-//    }
 }
