@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -66,6 +38,7 @@ import java.util.LinkedHashSet;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
+import java.util.Optional;
 import java.util.Queue;
 import java.util.Set;
 import java.util.concurrent.Callable;
@@ -89,6 +62,7 @@ import com.openexchange.database.Databases;
 import com.openexchange.databaseold.Database;
 import com.openexchange.exception.OXException;
 import com.openexchange.filestore.FileStorage;
+import com.openexchange.filestore.FileStorageCodes;
 import com.openexchange.filestore.FilestoreDataMoveListener;
 import com.openexchange.filestore.QuotaFileStorageExceptionCodes;
 import com.openexchange.groupware.filestore.FileLocationHandler;
@@ -267,7 +241,7 @@ public abstract class FilestoreDataMover implements Callable<Void> {
             throw e;
         } catch (RuntimeException e) {
             LOGGER.error("", e);
-            throw StorageException.storageExceotionFor(e);
+            throw StorageException.storageExceptionFor(e);
         }
         return null;
     }
@@ -333,7 +307,7 @@ public abstract class FilestoreDataMover implements Callable<Void> {
             thrown = e; throw new StorageException(e.getMessage(), e);
         } catch (RuntimeException e) {
             LOGGER.error("", e);
-            thrown = e; throw StorageException.storageExceotionFor(e);
+            thrown = e; throw StorageException.storageExceptionFor(e);
         } catch (Error x) {
             thrown = x; throw x;
         } catch (Throwable t) {
@@ -356,10 +330,11 @@ public abstract class FilestoreDataMover implements Callable<Void> {
      * @param dstStorage The destination storage
      * @param srcFullUri The fully qualifying URI from source storage
      * @param dstFullUri The fully qualifying URI from destination storage
+     * @param optionalFileNotFoundHandler The optional file-not-found handler
      * @return The old file name to new file name mapping; [src-file] --&gt; [dst-file]
      * @throws StorageException If copy operation fails
      */
-    protected CopyResult copyFiles(final Set<String> files, final FileStorage srcStorage, final FileStorage dstStorage, URI srcFullUri, URI dstFullUri) throws StorageException {
+    protected CopyResult copyFiles(final Set<String> files, final FileStorage srcStorage, final FileStorage dstStorage, URI srcFullUri, URI dstFullUri, Optional<FileNotFoundHandler> optionalFileNotFoundHandler) throws StorageException {
         if (files.isEmpty()) {
             return new CopyResult(Collections.<String, String> emptyMap(), null);
         }
@@ -442,6 +417,13 @@ public abstract class FilestoreDataMover implements Callable<Void> {
                         }
                         i++;
                     }
+                } catch (OXException e) {
+                    if (optionalFileNotFoundHandler.isPresent() && FileStorageCodes.FILE_NOT_FOUND.equals(e)) {
+                        optionalFileNotFoundHandler.get().handleFileNotFound(file, srcStorage);
+                    } else {
+                        // Re-throw
+                        throw e;
+                    }
                 } finally {
                     Streams.close(is);
                 }
